@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: iteratee
-version: 0.8.8.1
-id: iteratee-0.8.8.1-5f2a3dea4a066099100ed2c8ca77f086
+version: 0.8.8.2
+id: iteratee-0.8.8.2-799502059aab63af5a6eea48ad705ab8
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: John W. Lato <jwlato@gmail.com>
 stability: experimental
 homepage: http://www.tiresiaspress.us/haskell/iteratee
 package-url:
+synopsis: Iteratee-based I/O
 description: The Iteratee monad provides strict, safe, and functional I/O. In addition
              to pure Iteratee processors, file IO and combinator functions are provided.
              See @Data.Iteratee@ for full documentation.
@@ -24,26 +25,27 @@ exposed-modules: Data.Iteratee.IO.Posix Data.Iteratee.IO.Fd
                  Data.Iteratee.Iteratee Data.Iteratee.ListLike
                  Data.Iteratee.Parallel
 hidden-modules: Data.Iteratee.IO.Base
-import-dirs: /usr/local/lib/ghc/iteratee-0.8.8.1
-library-dirs: /usr/local/lib/ghc/iteratee-0.8.8.1
-hs-libraries: HSiteratee-0.8.8.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/iteratee-0.8.8.2
+library-dirs: /usr/local/lib/ghc/iteratee-0.8.8.2
+hs-libraries: HSiteratee-0.8.8.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: ListLike-1.0.1-b010b5418f8dec91ea5529e5d8204919
-         MonadCatchIO-transformers-0.2.2.0-21f55e3743ac58803f508355a9eecc56
-         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         parallel-3.1.0.1-df34ef713350b15281e4bf8cbc2c40d8
-         transformers-0.2.2.0-89265f646be3aed4f502cfc5eccd7c93
-         unix-2.4.2.0-41b8af27cfe8b819176ab06a4cb79133
+depends: ListLike-3.1.5-1befd1a7f59bc79b9d3424ec46d3fdf5
+         MonadCatchIO-transformers-0.3.0.0-3d9f2598a492284fcb08e73b1981b4a4
+         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
+         parallel-3.2.0.3-0c734151f27a50a329a35e705f0ba330
+         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
+         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-iteratee-0.8.8.1/html/iteratee.haddock
-haddock-html: /usr/local/share/doc/hs-iteratee-0.8.8.1/html
+haddock-interfaces: /usr/local/share/doc/hs-iteratee-0.8.8.2/html/iteratee.haddock
+haddock-html: /usr/local/share/doc/hs-iteratee-0.8.8.2/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
